#!/bin/bash

# Install FFmpeg
echo "[INFO] Installing FFmpeg..."
apt-get update
apt-get install -y ffmpeg
check_status "Failed to install FFmpeg."

# Clone the repository
echo "[INFO] Cloning the repository..."
git clone https://github.com/KwaiVGI/LivePortrait.git
if [ $? -ne 0 ]; then
    echo "[ERROR] Failed to clone repository."
    exit 1
fi

# Navigate into the repository folder
cd LivePortrait

# Install the required Python packages
echo "[INFO] Installing requirements..."
pip install -r requirements.txt

# Remove existing pretrained_weights folder if it exists
if [ -d "pretrained_weights" ]; then
    rm -rf pretrained_weights
fi

# Install Git LFS if not installed
if ! command -v git-lfs &> /dev/null; then
    echo "[INFO] Installing Git LFS..."
    curl -s https://packagecloud.io/install/repositories/github/git-lfs/script.deb.sh | bash
    apt-get update
    apt-get install -y git-lfs
    check_status "Failed to install Git LFS."
fi

# Download the models
echo "[INFO] Downloading the models..."
git lfs install
git clone https://huggingface.co/Aitrepreneur/pretrained_weights

# Launch the application
echo "[INFO] Launching the application..."
python app.py --share
